# Screen Config Watcher
A tool to watch OS screen configuration changes and change the OBS profile and scene collection accordingly.

## Getting display names

Run the `screen-config-watcher` script with the `-vv` and `-d` command line arguments. This will launch it in the 
dry-run mode, and you will be able to see the display names in the terminal.

# Auto-Start

See contents of the `samples` directory.
